@@ -9,10 +9,14 @@
 #' If you are unfamiliar with CSS, please see the
 #' \href{https://github.com/yihui/xaringan/wiki}{xaringan wiki on Github}
 #' providing CSS slide modification examples.
-#' @param css A vector of CSS file paths. A default CSS file is provided in this
+#' @param css A vector of CSS file paths. Two default CSS files
+#'   (\file{default.css} and \file{default-fonts.css}) are provided in this
 #'   package, which was borrowed from \url{https://remarkjs.com}. If the
-#'   character vector \code{css} contains the value \code{'default'}, the
-#'   default CSS will be used (e.g. \code{css = c('default', 'extra.css')}).
+#'   character vector \code{css} contains a value that does not end with
+#'   \code{.css}, it is supposed to be a built-in CSS file in this package,
+#'   e.g., for \code{css = c('default', 'extra.css')}), it means
+#'   \code{default.css} in this package and a user-provided \code{extra.css}. To
+#'   find out all built-in CSS files, use \code{xaringan:::list_css()}.
 #' @param self_contained Whether to produce a self-contained HTML file.
 #' @param seal Whether to generate a title slide automatically using the YAML
 #'   metadata of the R Markdown document (if \code{FALSE}, you should write the
@@ -61,13 +65,14 @@
 #' @importFrom htmltools tagList tags htmlEscape HTML
 #' @export
 moon_reader = function(
-  css = 'default', self_contained = FALSE, seal = TRUE, yolo = FALSE,
+  css = c('default', 'default-fonts'), self_contained = FALSE, seal = TRUE, yolo = FALSE,
   chakra = 'https://remarkjs.com/downloads/remark-latest.min.js', nature = list(),
   ...
 ) {
-  deps = if ('default' %in% css) {
-    css = setdiff(css, 'default')
-    list(example_css())
+  theme = grep('[.]css$', css, value = TRUE, invert = TRUE)
+  deps = if (length(theme)) {
+    css = setdiff(css, theme)
+    list(css_deps(theme))
   }
   tmp_js = tempfile('xaringan', fileext = '.js')  # write JS config to this file
   tmp_md = tempfile('xaringan', fileext = '.md')  # store md content here (bypass Pandoc)
@@ -77,17 +82,22 @@ moon_reader = function(
 
   if (isTRUE(countdown <- nature[['countdown']])) countdown = autoplay
   countdown_js = if (is.numeric(countdown) && countdown > 0) sprintf(
-    '(%s)(%d);', paste(readLines(pkg_resource('countdown.js')), collapse = '\n'), countdown
+    '(%s)(%d);', pkg_file('js/countdown.js'), countdown
   )
 
-  nature[['countdown']] = nature[['autoplay']] = NULL
+  before = nature[['beforeInit']]
+  nature[['countdown']] = nature[['autoplay']] = nature[['beforeInit']] = NULL
 
-  writeUTF8(as.character(tagList(
+  write_utf8(as.character(tagList(
     tags$script(src = chakra),
+    if (is.character(before)) if (self_contained) {
+      tags$script(HTML(file_content(before)))
+    } else {
+      lapply(before, function(s) tags$script(src = s))
+    },
     tags$script(HTML(paste(c(sprintf(
       'var slideshow = remark.create(%s);', if (length(nature)) knitr:::tojson(nature) else ''
-    ), "if (window.HTMLWidgets) slideshow.on('afterShowSlide', function (slide) {window.dispatchEvent(new Event('resize'));});",
-    '(function() {var d = document, s = d.createElement("style"), r = d.querySelector(".remark-slide-scaler"); if (!r) return; s.type = "text/css"; s.innerHTML = "@page {size: " + r.style.width + " " + r.style.height +"; }"; d.head.appendChild(s);})();',
+    ), pkg_file('js/show-widgets.js'), pkg_file('js/print-css.js'),
     play_js, countdown_js), collapse = '\n')))
   )), tmp_js)
 
@@ -139,11 +149,11 @@ moon_reader = function(
       metadata, input_file, runtime, knit_meta, files_dir, output_dir
     ) {
       res = split_yaml_body(input_file)
-      writeUTF8(res$yaml, input_file)
+      write_utf8(res$yaml, input_file)
       res$body = protect_math(res$body)
       content = htmlEscape(yolofy(res$body, yolo))
       Encoding(content) = 'UTF-8'
-      writeUTF8(content, tmp_md)
+      write_utf8(content, tmp_md)
       c(
         if (seal) c('--variable', 'title-slide=true'),
         if (!identical(body, res$body)) c('--variable', 'math=true')
